==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Fonte par défaut de l&apos;interface utilisateur</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Nom de la fonte :</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Style :</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Taille (points) :</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Gras et italique</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Les réglages suivants n&apos;affectent que les nouvelles applications</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Utiliser des fontes anti-aliasées</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Style d&apos;optimisation de l&apos;affichage :</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="118"/>
        <location filename="../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Plein</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Optimisation de l&apos;affichage</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resolution (DPI) :</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Auto optimisation</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Antialiasing des sous-pixels :</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuration de l&apos;apparence de LXQt</translation>
    </message>
    <message>
        <location filename="../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Thème d&apos;icones</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Thème de LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Substituer au papier-peint défini par l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../main.cpp" line="44"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuration de l&apos;apparence de LXQt</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="50"/>
        <source>Widget Style</source>
        <translation>Style des widgets</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="54"/>
        <source>Icons Theme</source>
        <translation>Thème d&apos;icones</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="58"/>
        <source>LXQt Theme</source>
        <translation>Thème de LXQt</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="62"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../../main.cpp" line="67"/>
        <source>Cursor</source>
        <translation>Curseur</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Style des widgets</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>Style des boutons de la barre d&apos;outils :</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>N&apos;afficher que l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>N&apos;afficher que le texte</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>Texte à côté de l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>Texte sous l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>Activer l&apos;item par simple clic</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Fonte par défaut de l&apos;interface utilisateur</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Nom de la fonte :</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Style :</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Taille (points) :</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Gras et italique</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Les réglages suivants n&apos;affectent que les nouvelles applications</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Utiliser des fontes anti-aliasées</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Style d&apos;optimisation de l&apos;affichage :</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Plein</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Optimisation de l&apos;affichage</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Resolution (DPI) :</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Auto optimisation</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Antialiasing des sous-pixels :</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuration de l&apos;apparence de LXQt</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Thème d&apos;icones</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Thème de LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Substituer au papier-peint défini par l&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Configuration de l&apos;apparence de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Widget Style</source>
        <translation>Style des widgets</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Icons Theme</source>
        <translation>Thème d&apos;icones</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="71"/>
        <source>LXQt Theme</source>
        <translation>Thème de LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="75"/>
        <source>Font</source>
        <translation>Fonte</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="80"/>
        <source>Cursor</source>
        <translation>Curseur</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Style des widgets</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>Style des boutons de la barre d&apos;outils :</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>N&apos;afficher que l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>N&apos;afficher que le texte</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>Texte à côté de l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>Texte sous l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>Par défaut</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>Activer l&apos;item par simple clic</translation>
    </message>
</context>
</TS>
